==> haskell-http-conduit-2.3.9.1-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-conduit
version:              2.3.9.1
visibility:           public
id:                   http-conduit-2.3.9.1-94aJgyTH95jHzekYpqTURg
key:                  http-conduit-2.3.9.1-94aJgyTH95jHzekYpqTURg
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/snoyberg/http-client
synopsis:
    HTTP client package with conduit interface and HTTPS support.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.

category:             Web, Conduit
abi:                  830ec0d53cb70e589aab0d93d61e3551
exposed:              True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-conduit
hs-libraries:         HShttp-conduit-2.3.9.1-94aJgyTH95jHzekYpqTURg
depends:
    aeson-2.1.2.1-PtSa2Du7ZnC9cVeQoj7Qs
    attoparsec-0.14.4-L0PdW4nkr6mJUEG3ZdEFXH
    attoparsec-aeson-2.1.0.0-C429V8OxWRA5PgvDXAo0Sx base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-KODsDTHe54N26FyzTue8CU
    conduit-extra-1.3.6-EUGr3AOWC9P9ZchDfeH4Md
    http-client-0.7.18-6kEwfjLGkicH9NZk52YwS4
    http-client-tls-0.3.6.4-12KLxoxiyAiL7y9aMSMPcS
    http-types-0.12.4-LxNt591TVq8DuxWpmMdPSD mtl-2.2.2
    resourcet-1.2.6-GnLJF89DOOQL8wsZDsu1Nb transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock

haddock-html:         /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-conduit-2.3.9.1-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-conduit
version:              2.3.9.1
visibility:           public
id:                   http-conduit-2.3.9.1-Ip8ZLhgyb9l45qSZlfq0gN
key:                  http-conduit-2.3.9.1-Ip8ZLhgyb9l45qSZlfq0gN
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/snoyberg/http-client
synopsis:
    HTTP client package with conduit interface and HTTPS support.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.

category:             Web, Conduit
abi:                  f20b85fe90ad1b3f67148ccb7b6c23eb
exposed:              True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-conduit
hs-libraries:         HShttp-conduit-2.3.9.1-Ip8ZLhgyb9l45qSZlfq0gN
depends:
    aeson-2.1.2.1-DotSWK7wQi51TFnSZ5tWn0
    attoparsec-0.14.4-L0PdW4nkr6mJUEG3ZdEFXH
    attoparsec-aeson-2.1.0.0-Ly7ne1G1x5A5Swpypl907n base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-9gTixXdrGe0HqsCoF12xcT
    conduit-extra-1.3.6-L20sNRqRGruUiEEr6OeGd
    http-client-0.7.18-KYUyTQMIjNWCKzpN1dCwUj
    http-client-tls-0.3.6.4-Ca4iBXT6jDLDT9N64mTqRo
    http-types-0.12.4-413g0VOw4W44aSPKSgUukJ mtl-2.2.2
    resourcet-1.2.6-GnLJF89DOOQL8wsZDsu1Nb transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock

haddock-html:         /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
